==> org-lsst-ccs-localdb-jar-4.1.10-sources.jar: org/lsst/ccs/localdb/utils/CreateDefaultDataGroups.java <==
package org.lsst.ccs.localdb.utils;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;
import org.lsst.ccs.bootstrap.BootstrapResourceUtils;
import org.lsst.ccs.utilities.logging.Logger;

/**
 * Migration utility for AgentState entities.
 * It empties the AgentState#getInnerStates manyToMany association, and replaces it
 * by an entry in the map componentStates map, with the empty String as key.
 * 
 * @author LSST CCS Team
 */
public class CreateDefaultDataGroups {
    
    private static final Logger log = Logger.getLogger("org.lsst.ccs.localdb");
    
    public static void main(String[] args) throws SQLException {
    
        String url, username, password, schemaName;
        Properties p = BootstrapResourceUtils.getBootstrapProperties("statusPersister");
        url = p.getProperty("hibernate.connection.url");
        username = p.getProperty("hibernate.connection.username");
        password = p.getProperty("hibernate.connection.password");
        String[] connSplit = url.split("/");
        schemaName = connSplit[connSplit.length - 1];
        
        try (Connection connection = DriverManager.getConnection(url + "?user=" + username + "&password=" + password)) {
            connection.setSchema(schemaName);
            // Create the ccs_dataGroup table if it is not there yet.
            PreparedStatement ps = connection.prepareStatement("SELECT * from INFORMATION_SCHEMA.TABLES where TABLE_SCHEMA=\""+schemaName+"\" and TABLE_NAME='ccs_dataGroup';");
            ResultSet rs = ps.executeQuery();
            if(!rs.next()) {
                log.info("creating a data group for each dataDesc");
                connection.prepareStatement("CREATE TABLE `ccs_dataGroup` ( `id` bigint(20) NOT NULL AUTO_INCREMENT,`agentName` varchar(255) DEFAULT NULL,`groupName` varchar(255) DEFAULT NULL,PRIMARY KEY (`id`),UNIQUE KEY `ccs_dataGr_agentNa_groupNa_u` (`agentName`,`groupName`))").execute();
                connection.prepareStatement("CREATE TABLE `ccs_dataGr_dataDe_b` (\n" +
                        "  `dataGroupId` bigint(20) NOT NULL,\n" +
                        "  `membersId` bigint(20) NOT NULL,\n" +
                        "  PRIMARY KEY (`dataGroupId`,`membersId`),\n" +
                        "  KEY `ccs_dataGrDe_membersId_dataDe_fk` (`membersId`),\n" +
                        "  CONSTRAINT `ccs_dataGrDe_dataGrId_dataGr_fk` FOREIGN KEY (`dataGroupId`) REFERENCES `ccs_dataGroup` (`id`),\n" +
                        "  CONSTRAINT `ccs_dataGrDe_membersId_dataDe_fk` FOREIGN KEY (`membersId`) REFERENCES `ccs_dataDesc` (`id`)\n" +
                        ")").execute();
                connection.prepareStatement("alter table ccs_metaDataData drop foreign key ccs_metaDaDa_dataDeId_dataDe_fk").execute();
                connection.prepareStatement("insert into ccs_dataGroup(id, agentName, groupName) select id, agentName, dataName from ccs_dataDesc").execute();
                connection.prepareStatement("insert into ccs_dataGr_dataDe_b (dataGroupId,membersId) select id, id from ccs_dataDesc").execute();
                connection.prepareStatement("alter table ccs_metaDataData add constraint ccs_metaDaDa_dataDeId_dataGr_fk foreign key (dataDescId) references ccs_dataGroup(id)").execute();
            }
            System.out.println("done");
        }
    } 
    
    
}

==> org-lsst-ccs-localdb-jar-4.1.42-20241118.220417-4-sources.jar: org/lsst/ccs/localdb/utils/CreateDefaultDataGroups.java <==
package org.lsst.ccs.localdb.utils;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;
import org.lsst.ccs.bootstrap.BootstrapResourceUtils;
import org.lsst.ccs.utilities.logging.Logger;

/**
 * Migration utility for AgentState entities.
 * It empties the AgentState#getInnerStates manyToMany association, and replaces it
 * by an entry in the map componentStates map, with the empty String as key.
 * 
 * @author LSST CCS Team
 */
public class CreateDefaultDataGroups {
    
    private static final Logger log = Logger.getLogger("org.lsst.ccs.localdb");
    
    public static void main(String[] args) throws SQLException {
    
        String url, username, password, schemaName;
        String propertiesFile = BootstrapResourceUtils.getBootstrapSystemProperties().getProperty("org.lsst.ccs.localdb.database.connection.file", "statusPersister.properties");
        Properties p = BootstrapResourceUtils.getBootstrapProperties(propertiesFile);
        url = p.getProperty("hibernate.connection.url");
        username = p.getProperty("hibernate.connection.username");
        password = p.getProperty("hibernate.connection.password");
        String[] connSplit = url.split("/");
        schemaName = connSplit[connSplit.length - 1];
        
        try (Connection connection = DriverManager.getConnection(url + "?user=" + username + "&password=" + password)) {
            connection.setSchema(schemaName);
            // Create the ccs_dataGroup table if it is not there yet.
            PreparedStatement ps = connection.prepareStatement("SELECT * from INFORMATION_SCHEMA.TABLES where TABLE_SCHEMA=\""+schemaName+"\" and TABLE_NAME='ccs_dataGroup';");
            ResultSet rs = ps.executeQuery();
            if(!rs.next()) {
                log.info("creating a data group for each dataDesc");
                connection.prepareStatement("CREATE TABLE `ccs_dataGroup` ( `id` bigint(20) NOT NULL AUTO_INCREMENT,`agentName` varchar(255) DEFAULT NULL,`groupName` varchar(255) DEFAULT NULL,PRIMARY KEY (`id`),UNIQUE KEY `ccs_dataGr_agentNa_groupNa_u` (`agentName`,`groupName`))").execute();
                connection.prepareStatement("CREATE TABLE `ccs_dataGr_dataDe_b` (\n" +
                        "  `dataGroupId` bigint(20) NOT NULL,\n" +
                        "  `membersId` bigint(20) NOT NULL,\n" +
                        "  PRIMARY KEY (`dataGroupId`,`membersId`),\n" +
                        "  KEY `ccs_dataGrDe_membersId_dataDe_fk` (`membersId`),\n" +
                        "  CONSTRAINT `ccs_dataGrDe_dataGrId_dataGr_fk` FOREIGN KEY (`dataGroupId`) REFERENCES `ccs_dataGroup` (`id`),\n" +
                        "  CONSTRAINT `ccs_dataGrDe_membersId_dataDe_fk` FOREIGN KEY (`membersId`) REFERENCES `ccs_dataDesc` (`id`)\n" +
                        ")").execute();
                connection.prepareStatement("alter table ccs_metaDataData drop foreign key ccs_metaDaDa_dataDeId_dataDe_fk").execute();
                connection.prepareStatement("insert into ccs_dataGroup(id, agentName, groupName) select id, agentName, dataName from ccs_dataDesc").execute();
                connection.prepareStatement("insert into ccs_dataGr_dataDe_b (dataGroupId,membersId) select id, id from ccs_dataDesc").execute();
                connection.prepareStatement("alter table ccs_metaDataData add constraint ccs_metaDaDa_dataDeId_dataGr_fk foreign key (dataDescId) references ccs_dataGroup(id)").execute();
            }
            System.out.println("done");
        }
    } 
    
    
}
